//-*-C++-*-  Enums used by the player.
// Copyright (C) 1997 by John P. Weiss
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Artistic License, included as the file
// "LICENSE" in the source code archive.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//
// You should have received a copy of the file "LICENSE", containing
// the License John Weiss originally placed this program under.
//
// This file is unreadable, because the comment-docifier is
// brainedead.  Try a "make srcdocs" to generate the
// HTML-documentation.
//
#ifndef _enums_h_
#define _enums_h_


/**
  Specifies the catalog database type.

  @memo specifies database type
  */
enum DBType {
   /** No database.
	@memo 0x00
	*/
   dbtNone = 0x00,
   /** WorkMan-type database.
	@memo 0x01
	*/
   dbtWM = 0x01,
   /** xmcd/TiKan-type database.
	@memo 0x02
	*/
   dbtTK = 0x02,
   /** Both databases.
	@memo 0x03
	*/
   dbtBoth = 0x03 };

/**
  Specifies the play state.  Designed to be OR-ed with the
  \Ref{PlayMode} and sent as a unit.

  @memo specifies the play state
  */
enum PlayState {
   /** The device is off.  Should only be used alone.
	@memo 0x01
	*/
   psOff = 0x01,
   /** The device is playing. Can be OR-ed with \Ref{psPaused}.
	@memo 0x02
	*/
   psPlaying = 0x02,
   /** The device is paused. Can [and should] be OR-ed with
	\Ref{psPlaying}.
	@memo 0x06
	*/
   psPaused = 0x06 };

/**
  AND this with an integer to remove the \Ref{PlayState} from an
  integer.
  @memo \Ref{PlayState} filter
  */
#define PLAY_STATE_MASK 0x07

/**
  Specifies the play mode.  Designed to be OR-ed with the
  \Ref{PlayState} and sent as a unit.

  None of these should be OR-ed together, as playstates are mutually
  exclusive beasts.
  @memo specifies the play mode
  */
enum PlayMode {
   /** Normal play.
	@memo 0x08
	*/
   pmNormal = 0x08,
   /** The entire CD or playlist repeats at the end.
	@memo 0x10
	*/
   pmRepeatAll = 0x10,
   /** The current item repeats when it finishes.
	@memo 0x20
	*/
   pmRepeat1 = 0x20,
   /** Shuffle mode.  The current playlist is in a random order, and
	gets re-randomized at the end, at which point it repeats.
	@memo 0x38
	*/
   pmShuffle  = 0x38 };

/**
  AND this with an integer to remove the \Ref{PlayMode} from an
  integer.
  @memo \Ref{PlayMode} filter
  */
#define PLAY_MODE_MASK 0x38

/**
  Specifies the time display mode.  Certain members can be OR-ed.

  @memo specifies the time display mode
  */
enum TimeMode {
   /** Display or emit the elapsed time [in either the current item or
	the entire program].  Cannot be combined with
	\Ref{tmRemaining}.
	@memo 0x00
	*/
   tmElapsed = 0x00,
   /** Display or emit the time remaining [in either the current item 
	or the entire program].  Cannot be combined with \Ref{tmElapsed}.
	@memo 0x01
	*/
   tmRemaining = 0x01, 
   /** OR this with \Ref{tmElapsed} or \Ref{tmRemaining} to indicate
	that it applies to the entire program.  By themselves,
	\Ref{tmElapsed} and \Ref{tmRemaining} apply only to the current
	item.
	@memo 0x02
	*/
   tmAll = 0x02 };

/**
  Specifies the CDROM device status.  Certain members can be OR-ed
  together [though it doesn't make sense to OR some...].


  @memo specifies the CDROM device status.
  */
enum CdStatus  { 
   /** Initialization and/or opening the CDROM device worked.  This
	flag is mutually exclusive with all of the others.
	@memo 0x00
	*/
   cdsOpenedOk = 0x00,
   /** The CDROM device has/is stopped.  Doesn't make much sense to OR
	this with \Ref{cdsPlaying}.
	@memo 0x01
	*/
   cdsStopped = 0x01,
   /** The CDROM device is playing.
	@memo 0x02
	*/
   cdsPlaying = 0x02,
   /** The CDROM device is paused.  Can [and should] be OR-ed with
	\Ref{cdsPlaying}.
	@memo 0x04
	*/
   cdsPaused = 0x04,
   /** The CDROM device is empty; it contains no CD.  Should not be
	OR-ed with \Ref{cdsStopped}, \Ref{cdsPlaying}, or
	\Ref{cdsPaused}, as that makes no sense.
	@memo 0x08
	*/
   cdsEmpty = 0x08,
   /** The CDROM device has completed play.  Good to OR with
	\Ref{cdsStopped}.
	@memo 0x10
	*/
   cdsComplete = 0x10,
   /** Some operation on the CDROM device failed, or the device had
	some other error.  Could be OR-ed with just about any other
	member of this enum [except \Ref{cdsOpenedOk}].
	@memo 0x20
	*/
   cdsError = 0x20,
   /** The CDROM tray is ejected.  Can [and should] be OR-ed with
	\Ref{cdsEmpty}.
	@memo 0x40
	*/
   cdsEjected = 0x40 };



#endif //_enums_h_
//||||||||||||||||||||||||||||||||
//
// End
// 
